#!/usr/bin/env python3

import serial
import sys
from tkinter import Tk, Canvas, Frame, BOTH

class Example(Frame):
    def __init__(self):
        super().__init__()
        self.master.title("Line sensor")
        self.pack(fill=BOTH, expand=1)
        self.canvas = Canvas(self)
        self.rects = []
        for i in range(8):
            self.rects.append(self.canvas.create_rectangle(0, 0, 1, 1))

    def redraw(self, values):
        step = self.winfo_width() / 8
        height = self.winfo_height()
        for i, val in enumerate(values[:8]):
            color = "#{0:02x}{0:02x}{0:02x}".format(int(values[i] / 1024 * 255))
            self.canvas.coords(self.rects[i], step * i, 0, (i + 1) * step, height)
            self.canvas.itemconfig(self.rects[i], fill=color)
        self.canvas.pack(fill=BOTH, expand=1)

if len(sys.argv) != 2:
    print("Wrong usage!")
    print("Usage: line_preview.py <Serial Port>")
    print("Requires 9600 bauds, comma separated values")
    sys.exit(1)

with serial.Serial(sys.argv[1], 9600, timeout=10) as s:
    root = Tk()
    ex = Example()
    root.geometry("400x250+300+300")
    ex.redraw([0, 10, 20, 30, 40, 50, 60, 70])

    def redraw():
        line = bytes(filter(lambda x: x < 128, s.readline()))
        vals = list(map(lambda x: 1024 - int(x), line.decode().split(",")[:8]))
        print(vals)
        ex.redraw(vals)
        root.after(10, redraw)

    root.after(10, redraw)
    root.mainloop()
